@@ -10,11 +10,14 @@ from ..utils import (
     OnDemandPagedList,
     age_restricted,
     clean_html,
+    extract_attributes,
     int_or_none,
     traverse_obj,
     try_get,
     unescapeHTML,
     unsmuggle_url,
+    update_url,
+    url_or_none,
     urlencode_postdata,
 )
 
@@ -97,24 +100,33 @@ class DailymotionBaseInfoExtractor(InfoExtractor):
 
 class DailymotionIE(DailymotionBaseInfoExtractor):
     _VALID_URL = r'''(?ix)
-                    https?://
+                    (?:https?:)?//
+                    (?:
+                        dai\.ly/|
                         (?:
-                            (?:(?:www|touch|geo)\.)?dailymotion\.[a-z]{2,3}/(?:(?:(?:(?:embed|swf|\#)/)|player(?:/\w+)?\.html\?)?video|swf)|
-                            (?:www\.)?lequipe\.fr/video
+                            (?:(?:www|touch|geo)\.)?dailymotion\.[a-z]{2,3}|
+                            (?:www\.)?lequipe\.fr
+                        )/
+                        (?:
+                            swf/(?!video)|
+                            (?:(?:crawler|embed|swf)/)?video/|
+                            player(?:/[\da-z]+)?\.html\?(?:video|(?P<is_playlist>playlist))=
                         )
-                        [/=](?P<id>[^/?_&]+)(?:.+?\bplaylist=(?P<playlist_id>x[0-9a-z]+))?
-                    '''
+                    )
+                    (?P<id>[^/?_&#]+)(?:[\w-]*\?playlist=(?P<playlist_id>x[0-9a-z]+))?
+    '''
     IE_NAME = 'dailymotion'
-    _EMBED_REGEX = [r'<(?:(?:embed|iframe)[^>]+?src=|input[^>]+id=[\'"]dmcloudUrlEmissionSelect[\'"][^>]+value=)(["\'])(?P<url>(?:https?:)?//(?:www\.)?dailymotion\.com/(?:embed|swf)/video/.+?)\1']
+    _EMBED_REGEX = [rf'(?ix)<(?:(?:embed|iframe)[^>]+?src=|input[^>]+id=[\'"]dmcloudUrlEmissionSelect[\'"][^>]+value=)["\'](?P<url>{_VALID_URL[5:]})']
     _TESTS = [{
         'url': 'http://www.dailymotion.com/video/x5kesuj_office-christmas-party-review-jason-bateman-olivia-munn-t-j-miller_news',
-        'md5': '074b95bdee76b9e3654137aee9c79dfe',
         'info_dict': {
             'id': 'x5kesuj',
             'ext': 'mp4',
             'title': 'Office Christmas Party Review –  Jason Bateman, Olivia Munn, T.J. Miller',
             'description': 'Office Christmas Party Review - Jason Bateman, Olivia Munn, T.J. Miller',
             'duration': 187,
+            'tags': 'count:5',
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
             'timestamp': 1493651285,
             'upload_date': '20170501',
             'uploader': 'Deadline',
@@ -122,18 +134,17 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
             'age_limit': 0,
             'view_count': int,
             'like_count': int,
-            'tags': ['hollywood', 'celeb', 'celebrity', 'movies', 'red carpet'],
-            'thumbnail': r're:https://(?:s[12]\.)dmcdn\.net/v/K456B1aXqIx58LKWQ/x1080',
         },
     }, {
         'url': 'https://geo.dailymotion.com/player.html?video=x89eyek&mute=true',
-        'md5': 'e2f9717c6604773f963f069ca53a07f8',
         'info_dict': {
             'id': 'x89eyek',
             'ext': 'mp4',
-            'title': "En quête d'esprit du 27/03/2022",
+            'title': 'En quête d\'esprit du 27/03/2022',
             'description': 'md5:66542b9f4df2eb23f314fc097488e553',
             'duration': 2756,
+            'tags': 'count:1',
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
             'timestamp': 1648383669,
             'upload_date': '20220327',
             'uploader': 'CNEWS',
@@ -141,8 +152,6 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
             'age_limit': 0,
             'view_count': int,
             'like_count': int,
-            'tags': ['en_quete_d_esprit'],
-            'thumbnail': r're:https://(?:s[12]\.)dmcdn\.net/v/Tncwi1YNg_RUl7ueu/x1080',
         },
     }, {
         'url': 'https://www.dailymotion.com/video/x2iuewm_steam-machine-models-pricing-listed-on-steam-store-ign-news_videogames',
@@ -152,8 +161,8 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
             'ext': 'mp4',
             'title': 'Steam Machine Models, Pricing Listed on Steam Store - IGN News',
             'description': 'Several come bundled with the Steam Controller.',
-            'thumbnail': r're:^https?:.*\.(?:jpg|png)$',
             'duration': 74,
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
             'timestamp': 1425657362,
             'upload_date': '20150306',
             'uploader': 'IGN',
@@ -162,20 +171,6 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
             'view_count': int,
         },
         'skip': 'video gone',
-    }, {
-        # Vevo video
-        'url': 'http://www.dailymotion.com/video/x149uew_katy-perry-roar-official_musi',
-        'info_dict': {
-            'title': 'Roar (Official)',
-            'id': 'USUV71301934',
-            'ext': 'mp4',
-            'uploader': 'Katy Perry',
-            'upload_date': '20130905',
-        },
-        'params': {
-            'skip_download': True,
-        },
-        'skip': 'VEVO is only available in some countries',
     }, {
         # age-restricted video
         'url': 'http://www.dailymotion.com/video/xyh2zz_leanna-decker-cyber-girl-of-the-year-desires-nude-playboy-plus_redband',
@@ -217,6 +212,125 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
     }, {
         'url': 'https://geo.dailymotion.com/player/xakln.html?video=x8mjju4&customConfig%5BcustomParams%5D=%2Ffr-fr%2Ftennis%2Fwimbledon-mens-singles%2Farticles-video',
         'only_matching': True,
+    }, {  # playlist-only
+        'url': 'https://geo.dailymotion.com/player/xf7zn.html?playlist=x7wdsj',
+        'only_matching': True,
+    }, {
+        'url': 'https://geo.dailymotion.com/player/xmyye.html?video=x93blhi',
+        'only_matching': True,
+    }, {
+        'url': 'https://www.dailymotion.com/crawler/video/x8u4owg',
+        'only_matching': True,
+    }, {
+        'url': 'https://www.dailymotion.com/embed/video/x8u4owg',
+        'only_matching': True,
+    }, {
+        'url': 'https://dai.ly/x94cnnk',
+        'only_matching': True,
+    }]
+    _WEBPAGE_TESTS = [{
+        # https://geo.dailymotion.com/player/xmyye.html?video=x93blhi
+        'url': 'https://www.financialounge.com/video/2024/08/01/borse-europee-in-rosso-dopo-la-fed-a-milano-volano-mediobanca-e-tim-edizione-del-1-agosto/',
+        'info_dict': {
+            'id': 'x93blhi',
+            'ext': 'mp4',
+            'title': 'OnAir - 01/08/24',
+            'description': '',
+            'duration': 217,
+            'timestamp': 1722505658,
+            'upload_date': '20240801',
+            'uploader': 'Financialounge',
+            'uploader_id': 'x2vtgmm',
+            'age_limit': 0,
+            'tags': [],
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
+            'view_count': int,
+            'like_count': int,
+        },
+    }, {
+        # https://geo.dailymotion.com/player/xf7zn.html?playlist=x7wdsj
+        'url': 'https://www.cycleworld.com/blogs/ask-kevin/ducati-continues-to-evolve-with-v4/',
+        'info_dict': {
+            'id': 'x7wdsj',
+        },
+        'playlist_mincount': 50,
+    }, {
+        # https://www.dailymotion.com/crawler/video/x8u4owg
+        'url': 'https://www.leparisien.fr/environnement/video-le-veloto-la-voiture-a-pedales-qui-aimerait-se-faire-une-place-sur-les-routes-09-03-2024-KCYMCPM4WFHJXMSKBUI66UNFPU.php',
+        'info_dict': {
+            'id': 'x8u4owg',
+            'ext': 'mp4',
+            'description': 'À bord du « véloto », l’alternative à la voiture pour la campagne',
+            'like_count': int,
+            'uploader': 'Le Parisien',
+            'upload_date': '20240309',
+            'view_count': int,
+            'tags': 'count:7',
+            'thumbnail': r're:https?://www\.leparisien\.fr/.+\.jpg',
+            'timestamp': 1709997866,
+            'age_limit': 0,
+            'uploader_id': 'x32f7b',
+            'title': 'VIDÉO. Le «\xa0véloto\xa0», la voiture à pédales qui aimerait se faire une place sur les routes',
+            'duration': 428.0,
+        },
+    }, {
+        # https://geo.dailymotion.com/player/xry80.html?video=x8vu47w
+        'url': 'https://www.metatube.com/en/videos/546765/This-frogs-decorates-Christmas-tree/',
+        'info_dict': {
+            'id': 'x8vu47w',
+            'ext': 'mp4',
+            'like_count': int,
+            'uploader': 'Metatube',
+            'upload_date': '20240326',
+            'view_count': int,
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
+            'timestamp': 1711496732,
+            'age_limit': 0,
+            'uploader_id': 'x2xpy74',
+            'title': 'Está lindas ranitas ponen su arbolito',
+            'duration': 28,
+            'description': 'Que lindura',
+            'tags': [],
+        },
+        'skip': 'Invalid URL',
+    }, {
+        # //geo.dailymotion.com/player/xysxq.html?video=k2Y4Mjp7krAF9iCuINM
+        'url': 'https://lcp.fr/programmes/avant-la-catastrophe-la-naissance-de-la-dictature-nazie-1933-1936-346819',
+        'info_dict': {
+            'id': 'k2Y4Mjp7krAF9iCuINM',
+            'ext': 'mp4',
+            'title': 'Avant la catastrophe la naissance de la dictature nazie 1933 -1936',
+            'description': 'md5:7b620d5e26edbe45f27bbddc1c0257c1',
+            'uploader': 'LCP Assemblée nationale',
+            'uploader_id': 'xbz33d',
+            'view_count': int,
+            'like_count': int,
+            'age_limit': 0,
+            'duration': 3220,
+            'tags': [],
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
+            'timestamp': 1739919947,
+            'upload_date': '20250218',
+        },
+        'skip': 'Invalid URL',
+    }, {
+        'url': 'https://forum.ionicframework.com/t/ionic-2-jw-player-dailymotion-player/83248',
+        'info_dict': {
+            'id': 'xwr14q',
+            'ext': 'mp4',
+            'title': 'Macklemore & Ryan Lewis - Thrift Shop (feat. Wanz)',
+            'age_limit': 0,
+            'description': 'md5:47fbe168b5a6ddc4a205e20dd6c841b2',
+            'duration': 234,
+            'like_count': int,
+            'tags': 'count:5',
+            'thumbnail': r're:https?://s[12]\.dmcdn\.net/v/.+',
+            'timestamp': 1358177670,
+            'upload_date': '20130114',
+            'uploader': 'Macklemore Official',
+            'uploader_id': 'x19qlwr',
+            'view_count': int,
+        },
     }]
     _GEO_BYPASS = False
     _COMMON_MEDIA_FIELDS = '''description
@@ -231,17 +345,36 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
         yield from super()._extract_embed_urls(url, webpage)
         for mobj in re.finditer(
                 r'(?s)DM\.player\([^,]+,\s*{.*?video[\'"]?\s*:\s*["\']?(?P<id>[0-9a-zA-Z]+).+?}\s*\);', webpage):
-            yield from 'https://www.dailymotion.com/embed/video/' + mobj.group('id')
+            yield 'https://www.dailymotion.com/embed/video/' + mobj.group('id')
+        for mobj in re.finditer(
+                r'(?s)<script [^>]*\bsrc=(["\'])(?:https?:)?//[\w-]+\.dailymotion\.com/player/(?:(?!\1).)+\1[^>]*>', webpage):
+            attrs = extract_attributes(mobj.group(0))
+            player_url = url_or_none(attrs.get('src'))
+            if not player_url:
+                continue
+            player_url = player_url.replace('.js', '.html')
+            if player_url.startswith('//'):
+                player_url = f'https:{player_url}'
+            if video_id := attrs.get('data-video'):
+                query_string = f'video={video_id}'
+            elif playlist_id := attrs.get('data-playlist'):
+                query_string = f'playlist={playlist_id}'
+            else:
+                continue
+            yield update_url(player_url, query=query_string)
 
     def _real_extract(self, url):
         url, smuggled_data = unsmuggle_url(url)
-        video_id, playlist_id = self._match_valid_url(url).groups()
+        video_id, is_playlist, playlist_id = self._match_valid_url(url).group('id', 'is_playlist', 'playlist_id')
 
-        if playlist_id:
-            if self._yes_playlist(playlist_id, video_id):
-                return self.url_result(
-                    'http://www.dailymotion.com/playlist/' + playlist_id,
-                    'DailymotionPlaylist', playlist_id)
+        if is_playlist:  # We matched the playlist query param as video_id
+            playlist_id = video_id
+            video_id = None
+
+        if self._yes_playlist(playlist_id, video_id):
+            return self.url_result(
+                f'http://www.dailymotion.com/playlist/{playlist_id}',
+                'DailymotionPlaylist', playlist_id)
 
         password = self.get_param('videopassword')
         media = self._call_api(
@@ -282,6 +415,8 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
         title = metadata['title']
         is_live = media.get('isOnAir')
         formats = []
+        subtitles = {}
+
         for quality, media_list in metadata['qualities'].items():
             for m in media_list:
                 media_url = m.get('url')
@@ -289,8 +424,10 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
                 if not media_url or media_type == 'application/vnd.lumberjack.manifest':
                     continue
                 if media_type == 'application/x-mpegURL':
-                    formats.extend(self._extract_m3u8_formats(
-                        media_url, video_id, 'mp4', live=is_live, m3u8_id='hls', fatal=False))
+                    fmt, subs = self._extract_m3u8_formats_and_subtitles(
+                        media_url, video_id, 'mp4', live=is_live, m3u8_id='hls', fatal=False)
+                    formats.extend(fmt)
+                    self._merge_subtitles(subs, target=subtitles)
                 else:
                     f = {
                         'url': media_url,
@@ -310,20 +447,18 @@ class DailymotionIE(DailymotionBaseInfoExtractor):
             if not f.get('fps') and f['format_id'].endswith('@60'):
                 f['fps'] = 60
 
-        subtitles = {}
         subtitles_data = try_get(metadata, lambda x: x['subtitles']['data'], dict) or {}
         for subtitle_lang, subtitle in subtitles_data.items():
             subtitles[subtitle_lang] = [{
                 'url': subtitle_url,
             } for subtitle_url in subtitle.get('urls', [])]
 
-        thumbnails = []
-        for height, poster_url in metadata.get('posters', {}).items():
-            thumbnails.append({
-                'height': int_or_none(height),
-                'id': height,
-                'url': poster_url,
-            })
+        thumbnails = traverse_obj(metadata, (
+            ('posters', 'thumbnails'), {dict.items}, lambda _, v: url_or_none(v[1]), {
+                'height': (0, {int_or_none}),
+                'id': (0, {str}),
+                'url': 1,
+            }))
 
         owner = metadata.get('owner') or {}
         stats = media.get('stats') or {}
@@ -409,7 +544,7 @@ class DailymotionSearchIE(DailymotionPlaylistBaseIE):
             'id': 'king of turtles',
             'title': 'king of turtles',
         },
-        'playlist_mincount': 90,
+        'playlist_mincount': 0,
     }]
     _SEARCH_QUERY = 'query SEARCH_QUERY( $query: String! $page: Int $limit: Int ) { search { videos( query: $query first: $limit page: $page ) { edges { node { xid } } } } } '
 
@@ -447,13 +582,13 @@ class DailymotionSearchIE(DailymotionPlaylistBaseIE):
 
 class DailymotionUserIE(DailymotionPlaylistBaseIE):
     IE_NAME = 'dailymotion:user'
-    _VALID_URL = r'https?://(?:www\.)?dailymotion\.[a-z]{2,3}/(?!(?:embed|swf|#|video|playlist|search)/)(?:(?:old/)?user/)?(?P<id>[^/?#]+)'
+    _VALID_URL = r'https?://(?:www\.)?dailymotion\.[a-z]{2,3}/(?!(?:embed|swf|#|video|playlist|search|crawler)/)(?:(?:old/)?user/)?(?P<id>[^/?#]+)'
     _TESTS = [{
         'url': 'https://www.dailymotion.com/user/nqtv',
         'info_dict': {
             'id': 'nqtv',
         },
-        'playlist_mincount': 152,
+        'playlist_mincount': 148,
     }, {
         'url': 'http://www.dailymotion.com/user/UnderProject',
         'info_dict': {
