@@ -22,7 +22,7 @@ class SunPornoIE(InfoExtractor):
             'thumbnail': r're:^https?://.*\.jpg$',
             'duration': 302,
             'age_limit': 18,
-        }
+        },
     }, {
         'url': 'http://embeds.sunporno.com/embed/807778',
         'only_matching': True,
@@ -32,7 +32,7 @@ class SunPornoIE(InfoExtractor):
         video_id = self._match_id(url)
 
         webpage = self._download_webpage(
-            'http://www.sunporno.com/videos/%s' % video_id, video_id)
+            f'http://www.sunporno.com/videos/{video_id}', video_id)
 
         title = self._html_extract_title(webpage)
         description = self._html_search_meta(
