@@ -5,7 +5,6 @@ import re
 from .common import InfoExtractor
 from .dailymotion import DailymotionIE
 from .odnoklassniki import OdnoklassnikiIE
-from .pladform import PladformIE
 from .sibnet import SibnetEmbedIE
 from .vimeo import VimeoIE
 from .youtube import YoutubeIE
@@ -334,11 +333,6 @@ class VKIE(VKBaseIE):
             'url': 'https://vk.com/video205387401_164765225',
             'only_matching': True,
         },
-        {
-            # pladform embed
-            'url': 'https://vk.com/video-76116461_171554880',
-            'only_matching': True,
-        },
         {
             'url': 'http://new.vk.com/video205387401_165548505',
             'only_matching': True,
@@ -456,10 +450,6 @@ class VKIE(VKBaseIE):
         if vimeo_url is not None:
             return self.url_result(vimeo_url, VimeoIE.ie_key())
 
-        pladform_url = PladformIE._extract_url(info_page)
-        if pladform_url:
-            return self.url_result(pladform_url, PladformIE.ie_key())
-
         m_rutube = re.search(
             r'\ssrc="((?:https?:)?//rutube\.ru\\?/(?:video|play)\\?/embed(?:.*?))\\?"', info_page)
         if m_rutube is not None:
